@@ -44,7 +44,12 @@ from breezy import osutils
 from breezy.commit import filter_excluded
 import breezy.bzr  # noqa: F401
 import breezy.git  # noqa: F401
-from breezy.errors import NotBranchError, NoSuchFile
+from breezy.errors import NotBranchError
+try:
+    from breezy.transport import NoSuchFile
+except ImportError:  # breezy < 3.3
+    from breezy.errors import NoSuchFile
+
 from breezy.patches import (
     parse_patches,
     apply_patches,
@@ -130,9 +135,7 @@ class AppliedPatches(object):
 
     def __enter__(self):
         if self.patches:
-            from breezy.transform import TransformPreview
-
-            self._tt = TransformPreview(self.tree)
+            self._tt = self.tree.preview_transform()
             apply_patches(self._tt, self.patches, prefix=self.prefix)
             return self._tt.get_preview_tree()
         else:
@@ -263,15 +266,17 @@ def tree_non_patches_changes(tree, patches_directory):
         list of TreeDelta objects
     """
     if patches_directory is None:
-        return
-    patches = list(read_quilt_patches(tree, patches_directory))
+        patches = []
+    else:
+        patches = list(read_quilt_patches(tree, patches_directory))
 
     # TODO(jelmer): What if patches are already applied on tree?
     with upstream_with_applied_patches(
         tree, patches
     ) as upstream_patches_tree, AppliedPatches(tree, patches) as patches_tree:
         for change in filter_excluded(
-            patches_tree.iter_changes(upstream_patches_tree), exclude=["debian"]
+            patches_tree.iter_changes(
+                upstream_patches_tree), exclude=["debian"]
         ):
             path = change.path[1]
             if path == "":
