@@ -31,7 +31,8 @@ MAINTAINER_EMAIL_MAP = {
     "python-modules-team@lists.alioth.debian.org": "python-team/modules",
     "python-apps-team@lists.alioth.debian.org": "python-team/applications",
     "debian-science-maintainers@lists.alioth.debian.org": "science-team",
-    "pkg-perl-maintainers@lists.alioth.debian.org": "perl-team/modules/packages",
+    "pkg-perl-maintainers@lists.alioth.debian.org":
+        "perl-team/modules/packages",
     "pkg-java-maintainers@lists.alioth.debian.org": "java-team",
     "pkg-ruby-extras-maintainers@lists.alioth.debian.org": "ruby-team",
     "pkg-clamav-devel@lists.alioth.debian.org": "clamav-team",
@@ -171,25 +172,29 @@ def _salsa_path_from_alioth_url(  # noqa: C901
     # These two regular expressions come from vcswatch:
     # https://salsa.debian.org/qa/qa/blob/master/data/vcswatch/vcswatch#L165
     if vcs_type.lower() == "git":
-        pat = "(https?|git)://(anonscm|git).debian.org/" "(cgit/|git/)?collab-maint/"
+        pat = ("(https?|git)://(anonscm|git).debian.org/"
+               "(cgit/|git/)?collab-maint/")
         if re.match(pat, alioth_url):
             return re.sub(pat, "debian/", alioth_url)
         pat = "(https?|git)://(anonscm|git).debian.org/(cgit/|git/)?users/"
         if re.match(pat, alioth_url):
             return re.sub(pat, "", alioth_url)
         m = re.match(
-            "(https?|git)://(anonscm|git).debian.org/(cgit/|git/)?(.+)", alioth_url
+            "(https?|git)://(anonscm|git).debian.org/(cgit/|git/)?(.+)",
+            alioth_url
         )
         if m:
             parts = m.group(4).split("/")
             for i in range(len(parts), 0, -1):
                 subpath = "/".join(parts[:i])
                 try:
-                    return GIT_PATH_RENAMES[subpath] + "/" + "/".join(parts[i:])
+                    return (GIT_PATH_RENAMES[subpath]
+                            + "/" + "/".join(parts[i:]))
                 except KeyError:
                     pass
         m = re.match(
-            "(https?|git)://(anonscm|git).debian.org/(cgit/|git/)?([^/]+)/", alioth_url
+            "(https?|git)://(anonscm|git).debian.org/(cgit/|git/)?([^/]+)/",
+            alioth_url
         )
         if m and m.group(4) == "debian-in" and "fonts-" in alioth_url:
             return re.sub(m.re, "fonts-team/", alioth_url)
@@ -197,7 +202,8 @@ def _salsa_path_from_alioth_url(  # noqa: C901
             new_name = TEAM_NAME_MAP[m.group(4)]
             return re.sub(m.re, new_name + "/", alioth_url)
         m = re.match(
-            "https?://alioth.debian.org/anonscm/(git/|cgit/)?([^/]+)/", alioth_url
+            "https?://alioth.debian.org/anonscm/(git/|cgit/)?([^/]+)/",
+            alioth_url
         )
         if m and m.group(2) in TEAM_NAME_MAP:
             new_name = TEAM_NAME_MAP[m.group(2)]
@@ -206,7 +212,8 @@ def _salsa_path_from_alioth_url(  # noqa: C901
     if vcs_type.lower() == "svn":
         if alioth_url.startswith("svn://svn.debian.org/pkg-perl/trunk"):
             return alioth_url.replace(
-                "svn://svn.debian.org/pkg-perl/trunk", "perl-team/modules/packages"
+                "svn://svn.debian.org/pkg-perl/trunk",
+                "perl-team/modules/packages"
             )
         if alioth_url.startswith("svn://svn.debian.org/pkg-lua/packages"):
             return alioth_url.replace(
@@ -219,9 +226,11 @@ def _salsa_path_from_alioth_url(  # noqa: C901
             parts = parsed_url.path.strip("/").split("/")
             if parts[0] == "svn":
                 parts.pop(0)
-            if len(parts) == 3 and parts[0] in TEAM_NAME_MAP and parts[2] == "trunk":
+            if (len(parts) == 3 and parts[0] in TEAM_NAME_MAP
+                    and parts[2] == "trunk"):
                 return "%s/%s" % (TEAM_NAME_MAP[parts[0]], parts[1])
-            if len(parts) == 3 and parts[0] in TEAM_NAME_MAP and parts[1] == "trunk":
+            if (len(parts) == 3 and parts[0] in TEAM_NAME_MAP
+                    and parts[1] == "trunk"):
                 return "%s/%s" % (TEAM_NAME_MAP[parts[0]], parts[2])
             if (
                 len(parts) == 4
@@ -237,7 +246,8 @@ def _salsa_path_from_alioth_url(  # noqa: C901
                 and parts[2] == "packages"
             ):
                 return "%s/%s" % (TEAM_NAME_MAP[parts[0]], parts[3])
-            if len(parts) > 3 and parts[0] in TEAM_NAME_MAP and parts[-2] == "trunk":
+            if (len(parts) > 3 and parts[0] in TEAM_NAME_MAP
+                    and parts[-2] == "trunk"):
                 return "%s/%s" % (TEAM_NAME_MAP[parts[0]], parts[-1])
             if (
                 len(parts) == 3
