@@ -460,6 +460,26 @@ def _scrub_obsolete(
     )
 
 
+def release_aliases(name):
+    from distro_info import DebianDistroInfo, UbuntuDistroInfo
+    ret = []
+    debian_distro_info = DebianDistroInfo()
+    ubuntu_distro_info = UbuntuDistroInfo()
+    FN_ALIAS_MAP = {
+        debian_distro_info.stable: 'stable',
+        debian_distro_info.old: 'oldstable',
+        debian_distro_info.devel: 'unstable',
+        ubuntu_distro_info.lts: 'lts',
+        ubuntu_distro_info.stable: 'stable'
+    }
+    for fn, alias in FN_ALIAS_MAP.items():
+        if fn() == name:
+            ret.append(alias)
+    if ret:
+        return '(%s)' % ', '.join(ret)
+    return ''
+
+
 def scrub_obsolete(
         wt: WorkingTree, subpath: str, compat_release: str,
         upgrade_release: str,
@@ -504,14 +524,20 @@ def scrub_obsolete(
     if update_changelog:
         lines = []
         for release, entries in summary.items():
-            lines.append("Remove constraints unnecessary since %s:" % release)
+            rev_aliases = release_aliases(release)
+            lines.append(
+                "Remove constraints unnecessary since %s" % release
+                + ((' ' + rev_aliases) if rev_aliases else '') + ':')
             lines.extend(["+ " + line for line in entries])
         add_changelog_entry(wt, changelog_path, lines)
         specific_files.append(changelog_path)
 
     lines = []
     for release, entries in summary.items():
-        lines.extend(["Remove constraints unnecessary since %s" % release, ""])
+        rev_aliases = release_aliases(release)
+        lines.extend(
+            ["Remove constraints unnecessary since %s" % release
+             + ((' ' + rev_aliases) if rev_aliases else ''), ""])
         lines.extend(["* " + line for line in entries])
     lines.extend(["", "Changes-By: deb-scrub-obsolete"])
 
@@ -531,11 +557,23 @@ def scrub_obsolete(
     return result
 
 
+def versions_dict():
+    import lintian_brush
+    import debmutate
+    import debian
+    return {
+        "lintian-brush": lintian_brush.version_string,
+        "debmutate": debmutate.version_string,
+        "debian": debian.__version__,
+    }
+
+
 def report_fatal(code: str, description: str) -> None:
     if os.environ.get('SVP_API') == '1':
         with open(os.environ['SVP_RESULT'], 'w') as f:
             json.dump({
                 'result_code': code,
+                'versions': versions_dict(),
                 'description': description}, f)
     logging.fatal('%s', description)
 
@@ -545,6 +583,7 @@ def report_okay(code: str, description: str) -> None:
         with open(os.environ['SVP_RESULT'], 'w') as f:
             json.dump({
                 'result_code': code,
+                'versions': versions_dict(),
                 'description': description}, f)
     logging.info('%s', description)
 
@@ -727,6 +766,7 @@ def main():  # noqa: C901
                 % upgrade_release,
                 "value": result.value(),
                 "debian": debian_context,
+                "versions": versions_dict(),
                 "context": {
                     "specific_files": result.specific_files,
                     "maintscript_removed": result.maintscript_removed,
